From 11c7855371439e85bd8b6fbfb4329e8eed6bd585 Mon Sep 17 00:00:00 2001
From: Campbell Barton <ideasman42@gmail.com>
Date: Tue, 12 Mar 2013 07:21:52 +0000
Subject: [PATCH] rename vrml2 export operator.

---
 io_scene_vrml2/__init__.py | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/io_scene_vrml2/__init__.py b/io_scene_vrml2/__init__.py
index 802fb7a75..977df5311 100644
--- a/io_scene_vrml2/__init__.py
+++ b/io_scene_vrml2/__init__.py
@@ -23,7 +23,7 @@ bl_info = {
     "author": "Campbell Barton",
     "blender": (2, 66, 0),
     "location": "File > Export",
-    "description": "Exports the active mesh object to VRML2, supporting vertex and material colors",
+    "description": "Exports mesh objects to VRML2, supporting vertex and material colors",
     "warning": "",
     "wiki_url": "http://wiki.blender.org/index.php/Extensions:2.6/Py/"
                 "Scripts/Import-Export/VRML2",
@@ -43,9 +43,9 @@ from bpy.props import CollectionProperty, StringProperty, BoolProperty, EnumProp
 from bpy_extras.io_utils import ExportHelper, path_reference_mode
 
 class ExportVRML(bpy.types.Operator, ExportHelper):
     """Export a single object as a VRML2, """ \
     """colors and texture coordinates"""
-    bl_idname = "export_mesh.vrml2"
+    bl_idname = "export_scene.vrml2"
     bl_label = "Export VRML2"
 
     filename_ext = ".wrl"
@@ -43,9 +43,9 @@ from bpy.props import CollectionProperty, StringProperty, BoolProperty, EnumProp
 
 class ExportVRML(bpy.types.Operator, ExportHelper):
-    """Export a single object as a VRML2, """ \
+    """Export mesh objects as a VRML2, """ \
     """colors and texture coordinates"""
-- 
GitLab